@@ -11,7 +11,7 @@ public:
 
   // Set/get the timer id that is being handled by this instance.
   void setID (long timerID);
-  long getID (void) const;
+  long getID () const;
 
   // Handle a timeout event, cancel, and close.
   virtual int handleEvent (const void *arg);
