@@ -8,8 +8,8 @@ class ACE_Svc_Export Adaptive_Lock_Performance_Test_Base : public Benchmark_Perf
 {
 public:
   virtual int init (int, ACE_TCHAR *[]) = 0;
-  virtual int fini (void);
-  virtual int svc (void);
+  virtual int fini ();
+  virtual int svc ();
 
   int set_lock (ACE_Lock *lock);
 
