@@ -97,7 +97,7 @@ public:
   virtual ~Client (void);
 
   // = Override <ACE_Event_Handler> methods.
-  virtual ACE_HANDLE get_handle (void) const;
+  virtual ACE_HANDLE get_handle () const;
   virtual int handle_input (ACE_HANDLE);
   virtual int handle_close (ACE_HANDLE handle,
                             ACE_Reactor_Mask close_mask);
@@ -125,9 +125,9 @@ private:
   /// The address to send messages to.
   ACE_INET_Addr remote_addr_;
 
-  ACE_UNIMPLEMENTED_FUNC (Client (void))
-  ACE_UNIMPLEMENTED_FUNC (Client (const Client &))
-  ACE_UNIMPLEMENTED_FUNC (Client &operator= (const Client &))
+  Client () = delete;
+  Client (const Client &) = delete;
+  Client &operator= (const Client &) = delete;
 };
 
 Client::Client (const ACE_INET_Addr &remote_addr)
@@ -154,7 +154,7 @@ Client::~Client (void)
 }
 
 ACE_HANDLE
-Client::get_handle (void) const
+Client::get_handle () const
 {
   return this->endpoint_.get_handle ();
 }
@@ -295,7 +295,7 @@ public:
   virtual ~Server (void);
 
   // = Override <ACE_Event_Handler> methods.
-  virtual ACE_HANDLE get_handle (void) const;
+  virtual ACE_HANDLE get_handle () const;
   virtual int handle_input (ACE_HANDLE);
   virtual int handle_close (ACE_HANDLE handle,
                             ACE_Reactor_Mask close_mask);
@@ -304,9 +304,9 @@ private:
   /// Receives datagrams.
   ACE_SOCK_Stream endpoint_;
 
-  ACE_UNIMPLEMENTED_FUNC (Server (void))
-  ACE_UNIMPLEMENTED_FUNC (Server (const Server &))
-  ACE_UNIMPLEMENTED_FUNC (Server &operator= (const Server &))
+  Server (void) = delete;
+  Server (const Server &) = delete;
+  Server &operator= (const Server &) = delete;
 };
 
 Server::Server (const ACE_INET_Addr &addr)
@@ -371,7 +371,7 @@ Server::~Server (void)
 }
 
 ACE_HANDLE
-Server::get_handle (void) const
+Server::get_handle () const
 {
   return this->endpoint_.get_handle ();
 }
@@ -559,6 +559,7 @@ ACE_TMAIN (int argc, ACE_TCHAR *argv[])
                                "\nbufsz must be <= %d\n",
                                BUFSIZ),
                               1);
+          break;
 
         case 'i':
           nsamples = ACE_OS::atoi (get_opt.opt_arg ());
